@@ -2,12 +2,12 @@
 """Main Controller"""
 
 from tg import TGController
-from tg import expose, flash, require, url, lurl, request, redirect, validate
+from tg import expose, flash, require, url, lurl, request, redirect, validate, abort
 from tg.i18n import ugettext as _, lazy_ugettext as l_
 from tg.decorators import cached_property
 
 from photos import model
-from photos.model import DBSession, Gallery
+from photos.model import DBSession, Gallery, Photo
 
 from repoze.what import predicates
 from tgext.crud import EasyCrudRestController
@@ -82,3 +82,8 @@ class RootController(TGController):
     @validate(dict(gallery=SQLAEntityConverter(Gallery)), error_handler=index)
     def gallery(self, gallery):
         return dict(gallery=gallery)
+
+    @expose('genshi:photos.templates.photo')
+    @validate(dict(photo=SQLAEntityConverter(Photo)), error_handler=lambda c:abort(404))
+    def photo(self, photo):
+        return dict(photo=photo)
